@@ -23,10 +23,7 @@ class HedgeOrchestrator(PipeOrchestrator):
                 out_arr.append(row)
         out_df: pd.DataFrame = pd.DataFrame(out_arr)
 
-        str_cols = [x for x in out_df.columns.tolist() if x.endswith("_words")]
-        num_cols = [x for x in out_df.columns.tolist() if( x.endswith("_count") or x.endswith("_ratio") )]
-        out_df[[str_cols]] = out_df[[str_cols]].fillna("")
-        out_df[[num_cols]] = out_df[[num_cols]].fillna(0)
+        
         return out_df
 
 
